% mat2tig(noun,P,w,nompt,numP0,denP0)
% 
%			This function generate a file (*.tmp) with templates to be used in TIG
%			Input argument:
%					- noun: It is a string with the path of the file (without the extension .tmp)
%					- P: It is a matrix with the templates [temp1,temp2,...]
%					     where temp1 is a complex colum vector xtemp1+j*ytemp1.
%                The maximum number of templates is 10.
%					- w: It is a vector with the frequencies (rad/s) [w1,w2,...] where the templates
%                has been computed
%					- nompt: It the row of P that contains the template points associated to the nominal plant
%           - numP0: It is a row vector with the numerator coefficients of the nominal plant
%           - denP0: It is a row vector with the denominator coefficients of the nominal plant
%
%		 Example1: mat2tig('templates',P,w,nompt) 
%      Example3: mat2tig('F:\\tig\templates',P,w,nompt)
%		 Example2: mat2tig('templates',P,w,nompt,numP0,denP0)  
%
%	J.M. Diaz 21-octuber-2005
%	Copyright (c)2005-2010 Dept. Informatica y Automatica. UNED (Spain)
function mat2tig(noun,P,w,nompt,numP0,denP0)

if nargin==4 |  nargin==6
	[row,col]=size(P);
	[fw,cw]=size(w);
if col<=10 & cw==col

rP=real(P);
iP=imag(P);


for h=1:col
   M(:,2*h-1)=rP(:,h);   
   M(:,2*h)=iP(:,h);      
end

file=[noun,'.tmp'];

fd=fopen(file,'w');
fprintf(fd,'INIT OF MATLAB TEMPLATE FILE\n\n');
fprintf(fd,'--\n\n');




[fil,col]=size(M);
for h=1:fil
		for k=1:col
			fprintf(fd,'%g',M(h,k));
         if k~=col 
            fprintf(fd,' ');
			end

	  end
		fprintf(fd,'\n\n');
	end
fprintf(fd,'--\n\n');




[fil,col]=size(w);
for h=1:fil
		for k=1:col
			fprintf(fd,'%g',w(h,k));
         if k~=col 
            fprintf(fd,' ');
			end

	  end
		fprintf(fd,'\n\n');
	end
fprintf(fd,'--\n\n');

fprintf(fd,'%d',nompt);
fprintf(fd,'\n\n');
fprintf(fd,'--\n\n');

if  nargin==6
   
	[fil,col]=size(numP0);
	for h=1:fil
			for k=1:col
				fprintf(fd,'%g',numP0(h,k));
       	  if k~=col 
       	     fprintf(fd,' ');
				end

		  end
			fprintf(fd,'\n\n');
	end
   fprintf(fd,'--\n\n');
   
   	[fil,col]=size(denP0);
	for h=1:fil
			for k=1:col
				fprintf(fd,'%g',denP0(h,k));
       	  if k~=col 
       	     fprintf(fd,' ');
				end

		  end
			fprintf(fd,'\n\n');
	end
   fprintf(fd,'--\n\n');

else     
	fprintf(fd,'vempty\n\n');
	fprintf(fd,'--\n\n');
	fprintf(fd,'vempty\n\n');
	fprintf(fd,'--\n\n');   
end



fprintf(fd,'FINAL OF MATLAB TEMPLATE FILE\n\n');
fprintf(fd,'--\n\n');
 
 fclose(fd);
 
else
    if rw~=col
       fprintf('\nERROR: The length of w is not equal to the number of templates.\n');  
    else   
       fprintf('\nWarning: TIG only works with 10 templates.\n');  
    end   
end

 
 
else
 fprintf('\nError: The number of input arguments must be 4 or 6.\n');  
end